package com.goldenwater.slaj.sins.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Mapper;
import com.goldenwater.slaj.sins.domain.ObjSins;

@Mapper
public interface ObjSinsMapper {
    ObjSins selectObjSinsByGuid(String guid);
    List<ObjSins> selectObjSinsList(ObjSins entity);
    int insertObjSins(ObjSins entity);
    int updateObjSins(ObjSins entity);
    int deleteObjSinsByGuid(String guid);
    int deleteObjSinsByGuids(String[] guids);
}
